@@ -15,6 +15,7 @@ pub(crate) mod report;
 mod scanlation_group;
 pub mod schema;
 mod search;
+mod settings;
 mod statistics;
 #[cfg(feature = "upload")]
 mod upload;
@@ -48,6 +49,7 @@ use crate::v5::report::ReportBuilder;
 use crate::v5::scanlation_group::ScanlationGroupBuilder;
 pub(crate) use crate::v5::schema::AuthTokens;
 use crate::v5::search::SearchBuilder;
+use crate::v5::settings::SettingsBuilder;
 use crate::v5::statistics::StatisticsBuilder;
 #[cfg(feature = "upload")]
 use crate::v5::upload::UploadBuilder;
@@ -264,6 +266,15 @@ impl MangaDexClient {
         SearchBuilder::new(self.http_client.clone())
     }
 
+    /// Get a builder for handling the settings endpoints.
+    ///
+    /// <https://api.mangadex.org/docs.html#tag/Settings>
+    // Not public yet as the settings endpoints are not stable as of MangaDex API v5.4.9.
+    #[allow(unused)]
+    fn settings(&self) -> SettingsBuilder {
+        SettingsBuilder::new(self.http_client.clone())
+    }
+
     /// Get a builder for handling the statistics endpoints.
     ///
     /// <https://api.mangadex.org/docs.html#tag/Statistics>
