@@ -110,6 +110,7 @@ mod tests {
                     "title": chapter_title,
                     "volume": "1",
                     "chapter": "1.5",
+                    "pages": 4,
                     "translatedLanguage": "en",
                     "uploader": uploader_id,
                     "version": 1,
@@ -141,6 +142,7 @@ mod tests {
         assert_eq!(res.data.attributes.title, chapter_title);
         assert_eq!(res.data.attributes.volume, Some("1".to_string()));
         assert_eq!(res.data.attributes.chapter, Some("1.5".to_string()));
+        assert_eq!(res.data.attributes.pages, 4);
         assert_eq!(res.data.attributes.translated_language, Language::English);
         assert_eq!(res.data.attributes.uploader, Some(uploader_id));
         assert_eq!(res.data.attributes.version, 1);
