@@ -28,6 +28,7 @@ mod upload_session;
 #[cfg(feature = "upload")]
 mod upload_session_file;
 mod user;
+mod user_settings;
 
 use std::collections::HashMap;
 
@@ -66,6 +67,7 @@ pub(crate) use upload_session::UploadSessionResponse;
 #[cfg(feature = "upload")]
 pub(crate) use upload_session_file::{UploadSessionFileAttributes, UploadSessionFileData};
 pub(crate) use user::UserAttributes;
+pub(crate) use user_settings::UserSettingsAttributes;
 
 pub type AtHomeServerResponse = Result<AtHomeServer>;
 
@@ -136,6 +138,8 @@ pub type UserData = ApiData<UserObject>;
 pub type UserResponse = Result<UserData>;
 pub type UserListResponse = Result<Results<UserObject>>;
 
+pub type UserSettingsResponse = Result<UserSettingsAttributes>;
+
 #[derive(Deserialize)]
 #[serde(tag = "result", remote = "std::result::Result")]
 enum ApiResultDef<T, E> {
