@@ -303,6 +303,7 @@ mod tests {
                 "title": chapter_title,
                 "volume": "1",
                 "chapter": "2.5",
+                "pages": 4,
                 "translatedLanguage": "en",
                 "uploader": uploader_id,
                 "version": 1,
@@ -342,6 +343,7 @@ mod tests {
         assert_eq!(res.attributes.title, chapter_title);
         assert_eq!(res.attributes.volume, Some("1".to_string()));
         assert_eq!(res.attributes.chapter, Some("2.5".to_string()));
+        assert_eq!(res.attributes.pages, 4);
         assert_eq!(res.attributes.translated_language, Language::English);
         assert_eq!(res.attributes.uploader, Some(uploader_id));
         assert_eq!(res.attributes.external_url, None);
